# Summary

- [Introduction](./introduction.md)
- [Installation](./install.md)
- [Overview](./overview.md)
- [Configuration](./configuration.md)
	- [Apptainer Configuration](./apptainer.md)
		- [Apptainer Overview](./apptainer-introduction.md)
		- [Mutable Filesystem](./apptainer-mutable-filesystem.md)
		- [Input Files](./apptainer-input-files.md)
		- [Storing Results](./apptainer-storing-results.md)
		- [Packaging Solvers](./apptainer-packaging-solvers.md)
		- [Running Locally](./apptainer-running-locally.md)
	- [Python Jobs](./python.md)
		- [Build Scripts](./python-build-scripts.md)
		- [Input Files](./python-input-files.md)
		- [Storing Results](./python-storing-results.md)
		- [Execution Scripts](./python-execution-scripts.md)
		- [Full Example](./python-full-example.md)
- [Command Basics](./commands.md)
- [Python Api](./python_api.md)
- [Capabilities](capabilities.md)
- [Admin Setup](./admin_setup.md)
	- [Head Node Setup](./head_node_setup.md)
	- [Compute Node Setup](./compute_node_setup.md)
